==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm5/lib/GeographicPolylineSeriesView_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { GeographicShapeSeriesBaseView } from "./GeographicShapeSeriesBaseView";
import { Defaults } from "igniteui-webcomponents-charts";
import { ScatterPolylineSeries } from "igniteui-webcomponents-charts";
import { markType, runOn, delegateCombine, markDep } from "igniteui-webcomponents-core";
import { GeographicShapeSeriesBase } from "./GeographicShapeSeriesBase";
import { StyleSelector } from "igniteui-webcomponents-charts";
import { DependencyProperty } from "igniteui-webcomponents-core";
import { Style } from "igniteui-webcomponents-core";
import { PropertyMetadata } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
var GeographicPolylineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicPolylineSeriesView, _super);
    function GeographicPolylineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.cl = null;
        _this.cl = a;
        return _this;
    }
    GeographicPolylineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.cl.iv = Defaults.n;
        }
    };
    GeographicPolylineSeriesView.prototype.b5 = function () {
        _super.prototype.b5.call(this);
        this.cl.t5.wv = this.cl.vb;
        this.cl.t5.w0 = this.cl.vj;
    };
    GeographicPolylineSeriesView.prototype.cm = function () {
        this.cl.t5.wv = this.cl.vb;
    };
    GeographicPolylineSeriesView.prototype.cn = function () {
        this.cl.t5.w0 = this.cl.vj;
    };
    GeographicPolylineSeriesView.$t = markType(GeographicPolylineSeriesView, 'GeographicPolylineSeriesView', GeographicShapeSeriesBaseView.$);
    return GeographicPolylineSeriesView;
}(GeographicShapeSeriesBaseView));
export { GeographicPolylineSeriesView };
/**
 * @hidden
 */
var GeographicPolylineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicPolylineSeries, _super);
    function GeographicPolylineSeries() {
        var _this = _super.call(this) || this;
        _this.styleShape = null;
        _this.ab = GeographicPolylineSeries.$;
        return _this;
    }
    GeographicPolylineSeries.prototype.bc = function () {
        return new GeographicPolylineSeries();
    };
    GeographicPolylineSeries.prototype.get_e5 = function () {
        return true;
    };
    GeographicPolylineSeries.prototype.cd = function () {
        return new GeographicPolylineSeriesView(this);
    };
    GeographicPolylineSeries.prototype.o2 = function (a) {
        _super.prototype.o2.call(this, a);
        this.vc = a;
    };
    GeographicPolylineSeries.prototype.t4 = function () {
        var a = new ScatterPolylineSeries();
        a.styleShape = delegateCombine(a.styleShape, runOn(this, this.vg));
        return a;
    };
    GeographicPolylineSeries.prototype.vg = function (a, b) {
        if (this.styleShape != null) {
            this.styleShape(this, b);
        }
    };
    GeographicPolylineSeries.prototype.pa = function (a, b, c, d) {
        _super.prototype.pa.call(this, a, b, c, d);
        switch (b) {
            case GeographicPolylineSeries.$$p[1]:
                this.vc.cm();
                break;
            case GeographicPolylineSeries.$$p[0]:
                this.vc.cn();
                break;
        }
    };
    GeographicPolylineSeries.$t = markType(GeographicPolylineSeries, 'GeographicPolylineSeries', GeographicShapeSeriesBase.$);
    GeographicPolylineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, GeographicPolylineSeries, 'raisePropertyChanged', ['ShapeStyle:vj:vh', [Style.$, null], 'ShapeStyleSelector:vb:vi', [StyleSelector.$, null]]);
    return GeographicPolylineSeries;
}(GeographicShapeSeriesBase));
export { GeographicPolylineSeries };

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm5/lib/GeographicPolylineSeriesView_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { GeographicShapeSeriesBaseView } from "./GeographicShapeSeriesBaseView";
import { Defaults } from "igniteui-webcomponents-charts";
import { ScatterPolylineSeries } from "igniteui-webcomponents-charts";
import { markType, runOn, delegateCombine, markDep } from "igniteui-webcomponents-core";
import { GeographicShapeSeriesBase } from "./GeographicShapeSeriesBase";
import { StyleSelector } from "igniteui-webcomponents-charts";
import { DependencyProperty } from "igniteui-webcomponents-core";
import { Style } from "igniteui-webcomponents-core";
import { PropertyMetadata } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
var GeographicPolylineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicPolylineSeriesView, _super);
    function GeographicPolylineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.cp = null;
        _this.cp = a;
        return _this;
    }
    GeographicPolylineSeriesView.prototype.ax = function () {
        _super.prototype.ax.call(this);
        if (!this.r) {
            this.cp.jp = Defaults.n;
        }
    };
    GeographicPolylineSeriesView.prototype.b9 = function () {
        _super.prototype.b9.call(this);
        this.cp.w2.aaa = this.cp.yh;
        this.cp.w2.aaf = this.cp.yp;
    };
    GeographicPolylineSeriesView.prototype.cq = function () {
        this.cp.w2.aaa = this.cp.yh;
    };
    GeographicPolylineSeriesView.prototype.cr = function () {
        this.cp.w2.aaf = this.cp.yp;
    };
    GeographicPolylineSeriesView.$t = markType(GeographicPolylineSeriesView, 'GeographicPolylineSeriesView', GeographicShapeSeriesBaseView.$);
    return GeographicPolylineSeriesView;
}(GeographicShapeSeriesBaseView));
export { GeographicPolylineSeriesView };
/**
 * @hidden
 */
var GeographicPolylineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicPolylineSeries, _super);
    function GeographicPolylineSeries() {
        var _this = _super.call(this) || this;
        _this.styleShape = null;
        _this.ab = GeographicPolylineSeries.$;
        return _this;
    }
    GeographicPolylineSeries.prototype.bk = function () {
        return new GeographicPolylineSeries();
    };
    GeographicPolylineSeries.prototype.get_fr = function () {
        return true;
    };
    GeographicPolylineSeries.prototype.ct = function () {
        return new GeographicPolylineSeriesView(this);
    };
    GeographicPolylineSeries.prototype.q1 = function (a) {
        _super.prototype.q1.call(this, a);
        this.yi = a;
    };
    GeographicPolylineSeries.prototype.w1 = function () {
        var a = new ScatterPolylineSeries();
        a.styleShape = delegateCombine(a.styleShape, runOn(this, this.ym));
        return a;
    };
    GeographicPolylineSeries.prototype.ym = function (a, b) {
        if (this.styleShape != null) {
            this.styleShape(this, b);
        }
    };
    GeographicPolylineSeries.prototype.ra = function (a, b, c, d) {
        _super.prototype.ra.call(this, a, b, c, d);
        switch (b) {
            case GeographicPolylineSeries.$$p[1]:
                this.yi.cq();
                break;
            case GeographicPolylineSeries.$$p[0]:
                this.yi.cr();
                break;
        }
    };
    GeographicPolylineSeries.$t = markType(GeographicPolylineSeries, 'GeographicPolylineSeries', GeographicShapeSeriesBase.$);
    GeographicPolylineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, GeographicPolylineSeries, 'raisePropertyChanged', ['ShapeStyle:yp:yn', [Style.$, null], 'ShapeStyleSelector:yh:yo', [StyleSelector.$, null]]);
    return GeographicPolylineSeries;
}(GeographicShapeSeriesBase));
export { GeographicPolylineSeries };
